﻿//==============================================================================
// File: Configuration.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Diagnostics;

namespace WpfRcp.PropertyModel.Cfg
{
    /// <summary>
    /// Represents a simple configuration for use with <see cref="IPropertyContainer"/> implementations.
    /// </summary>
    public static class Configuration
    {
        private static ICollectionFactory CurrentCollectionFactory;

        /// <summary>
        /// Gets or sets a collection factory.
        /// </summary>
        public static ICollectionFactory CollectionFactory
        {
            get
            {
                if (CurrentCollectionFactory == null)
                {
                    Debug.WriteLine("Collection factory is null. Falling back to ValidatableObservableCollection implementation.");
                    CurrentCollectionFactory = new ObservableCollectionFactory();
                }
                return CurrentCollectionFactory;
            }
            set
            {
                if (CurrentCollectionFactory != null)
                {
                    throw new InvalidOperationException(
                        "CollectionFactory can be initialized only once. Make sure CollectionFactory was not used before this call (which triggers default initialization) or was not already set.");
                }
                CurrentCollectionFactory = value;
            }
        }
    }
}