﻿//==============================================================================
// File: ICollectionFactory.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Collections.Generic;
using System.Collections.Specialized;

namespace WpfRcp.PropertyModel.Cfg
{
    /// <summary>
    /// Interface for creating collections of elements specific for application domain model requirements. 
    /// Collections at minimum should implement IList{T} and INotifyCollectionChanged interfaces.
    /// </summary>
    public interface ICollectionFactory
    {
        /// <summary>
        /// Returns new empty collection of desired generic type.
        /// </summary>
        /// <typeparam name="T">Type of element which collection contains.</typeparam>
        /// <returns>New instance of collection.</returns>
        IList<T> Create<T>();

        /// <summary>
        /// Returns a collection of desired generic type with items from original collection copied.
        /// </summary>
        /// <typeparam name="T">Type of element which collection contains.</typeparam>
        /// <param name="original">Collection to copy items from.</param>
        /// <returns>New instance of collection.</returns>
        IList<T> Create<T>(IEnumerable<T> original);

        /// <summary>
        /// Returns new empty collection of desired generic type, additionally hooking CollectionChanged event to handler.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="collectionChangedEventHandler"></param>
        /// <returns></returns>
        IList<T> Create<T>(NotifyCollectionChangedEventHandler collectionChangedEventHandler);

        /// <summary>
        /// Gets exact type of the collection that this factory
        /// </summary>
        Type CollectionType { get; }
    }
}