﻿//==============================================================================
// File: ObservableCollectionFactory.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Collections.Specialized;

namespace WpfRcp.PropertyModel.Cfg
{
    /// <summary>
    /// Represents a collection factory which produces <see cref="ObservableCollection{T}"/> instances.
    /// </summary>
    public class ObservableCollectionFactory : ICollectionFactory
    {
        public IList<T> Create<T>()
        {
            return new ObservableCollection<T>();
        }

        public IList<T> Create<T>(IEnumerable<T> original)
        {
            return new ObservableCollection<T>(original);
        }

        public IList<T> Create<T>(NotifyCollectionChangedEventHandler collectionChangedEventHandler)
        {
            if (collectionChangedEventHandler == null)
                throw new ArgumentNullException("collectionChangedEventHandler");

            var collection = new ObservableCollection<T>();
            collection.CollectionChanged += collectionChangedEventHandler;
            
            return collection;
        }

        public Type CollectionType
        {
            get { return typeof (ObservableCollection<>); }
        }
    }
}
