﻿//==============================================================================
// File: IUnsafeMultiMap.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Collections.Generic;

namespace WpfRcp.PropertyModel.Collections
{
    /// <summary>
    /// Represents a <see cref="IMultiMap{TKey,TValue}"/> which also has some unsafe methods.
    /// </summary>
    /// <remarks>
    /// Unsafe methods always assume that a given key exists in the map.
    /// </remarks>
    /// <typeparam name="TKey">Key's type.</typeparam>
    /// <typeparam name="TValue">Value's type.</typeparam>
    public interface IUnsafeMultiMap<TKey, TValue> : IMultiMap<TKey, TValue>
    {
        /// <summary>
        /// Adds an item. This method does not check if the given key is present
        /// in the MultiMap. If the key is not present, an exception is thrown.
        /// </summary>
        /// <param name="key">The key to store the value under.</param>
        /// <param name="value">The value to add.</param>
        void UnsafeAdd(TKey key, TValue value);

        /// <summary>
        /// Removes the specified item. This method does not check if the given key is present
        /// in the MultiMap. If the key is not present, an exception is thrown.
        /// </summary>
        /// <param name="key">The key the item is stored under.</param>
        /// <param name="value">The value to remove.</param>
        /// <returns><see langword="True"/> if the item was removed successfully, otherwise <see langword="false"/>.</returns>
        bool UnsafeRemove(TKey key, TValue value);

        /// <summary>
        /// Gets the values associated with the specified key. This method does
        /// not check if the given key is present in the MultiMap. If the key
        /// is not present, an exception is thrown.
        /// </summary>
        /// <param name="key">The requested key.</param>
        /// <returns>A list of values associated with the key.</returns>
        ICollection<TValue> UnsafeGet(TKey key);
    }
}