﻿//==============================================================================
// File: IContentComparable.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

namespace WpfRcp.PropertyModel.Core
{
    /// <summary>
    /// Defines an interface used when the content of a <see cref="IPropertyContainer"/>
    /// is compared using ContentEquals method. If you don't want to compare two
    /// properties using standard Equals method, implement this interface on these
    /// properties' type. This interface is typically (but not necessarily) implemented
    /// by a <see cref="IPropertyContainer"/>.
    /// </summary>
    public interface IContentComparable
    {
        /// <summary>
        /// Compares content of two objects.
        /// </summary>
        /// <param name="target">Target object to be compared against.</param>
        /// <returns>0 if target object equals to current object. Nonzero otherwise.</returns>
        int CompareContentTo(object target);
    }
}