﻿//==============================================================================
// File: MetapropertyInfo.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Diagnostics;

namespace WpfRcp.PropertyModel
{
    /// <summary>
    /// Represents a meta property key used for writing read-only properties.
    /// </summary>
    [Serializable]
    public sealed class MetaPropertyKey
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MetaPropertyKey"/> class.
        /// </summary>
        /// <param name="metaProperty">Meta property.</param>
        internal MetaPropertyKey(MetaProperty metaProperty)
        {
            Debug.Assert(metaProperty != null);
            MetaProperty = metaProperty;
        }

        /// <summary>
        /// Gets a meta property associated with this key.
        /// </summary>
        public MetaProperty MetaProperty { get; private set; }
    }
}