﻿//==============================================================================
// File: PropertyOptions.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;

namespace WpfRcp.PropertyModel
{
    /// <summary>
    /// Represents various options that can be applied for a property.
    /// </summary>
    [Flags]
    public enum PropertyOptions
    {
        /// <summary>
        /// Indicates no special options for a property.
        /// </summary>
        None = 0,

        /// <summary>
        /// Indicates that the property is matchable.
        /// </summary>
        Matchable = 1,

        /// <summary>
        /// Indicates that when invalid value is being set for a property,
        /// an <see cref="ArgumentException"/> exception is thrown.
        /// </summary>
        ThrowsOnValidationError = 2,

        /// <summary>
        /// Indicates that when a value changes internally, a property which contained it revalidates.
        /// </summary>
        RevalidatesOnStateChanged = 4,

        /// <summary>
        /// Indicates that this propery should not be serialized.
        /// </summary>
        NonSerializable = 8,

        /// <summary>
        /// Indicates that the property is visible in the UI.
        /// </summary>
        UIVisible = 16
    }
}