﻿//==============================================================================
// File: IPropertyScope.cs
// Created: 2010-07-20
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;

namespace WpfRcp.PropertyModel.Scope
{
    /// <summary>
    /// Represents a property scope.
    /// </summary>
    public interface IPropertyScope
    {
        /// <summary>
        /// Gets value, if this scope is sealed.
        /// </summary>
        bool IsSealed { get; }

        /// <summary>
        /// Seals this scope, which disables further property collection modification.
        /// </summary>
        void Seal();

        /// <summary>
        /// Method that returns all dynamic properties registered in the registry.
        /// </summary>
        /// <param name="container">The container for which <see cref="MetaPropertyCollection"/> is being returned.</param>
        /// <returns>Returns all dynamic properties registered in the registry for given <see cref="IPropertyContainer"/> container.</returns>
        /// <remarks>The <paramref name="container"/> parameter can be null.</remarks>
        MetaPropertyCollection GetDynamicProperties(IPropertyContainer container);
    }
}