﻿//==============================================================================
// File: DelegateValidationRule.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Diagnostics;

namespace WpfRcp.PropertyModel.Validation
{
    [Serializable]
    internal sealed class DelegateValidationRule : ValidationRule
    {
        private readonly ValidateValueCallback m_Callback;

        public DelegateValidationRule(ValidateValueCallback callback)
        {
            Debug.Assert(callback != null);
            m_Callback = callback;
        }

        protected override ValidationResult DoValidate(object value, ValidationArgs e)
        {
            return m_Callback.Invoke(value, e);
        }

        public override bool Equals(object obj)
        {
            return m_Callback.Equals(obj);
        }

        public override int GetHashCode()
        {
            return m_Callback.GetHashCode();
        }
    }
}