﻿//==============================================================================
// File: IRuleListChanged.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;

namespace WpfRcp.PropertyModel.Validation
{
    /// <summary>
    /// Defines an interface containing <see cref="RuleListChanged"/> event.
    /// </summary>
    public interface IRuleListChanged
    {
        /// <summary>
        /// Event fired when a rule list changes.
        /// </summary>
        event EventHandler<RuleListChangedEventArgs> RuleListChanged;
    }

    /// <summary>
    /// Defines an event arguments for the <see cref="IRuleListChanged.RuleListChanged"/> event.
    /// </summary>
    public class RuleListChangedEventArgs : EventArgs
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="RuleListChangedEventArgs"/> class.
        /// </summary>
        /// <param name="newRule">Newly added <see cref="IValidationRule"/>.</param>
        public RuleListChangedEventArgs(IValidationRule newRule)
        {
            NewRule = newRule;
        }

        /// <summary>
        /// Gets newly added <see cref="IValidationRule"/>.
        /// </summary>
        public IValidationRule NewRule { get; private set; }
    }
}