﻿//==============================================================================
// File: INotifyScopeChanged.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Collections;
using System.Collections.Generic;

namespace WpfRcp.PropertyModel.Validation
{
    /// <summary>
    /// Represents simple collection of <see cref="IObjectValidationRule"/> rules.
    /// </summary>
    [Serializable]
    public class ObjectRuleList : IObjectRuleList
    {
        private readonly List<IObjectValidationRule> m_Rules;
        private readonly List<ValidationResult> m_ValidationResults;

        /// <summary>
        /// Initializes a new instance of the <see cref="ObjectRuleList"/> class.
        /// </summary>
        public ObjectRuleList()
        {
            m_Rules = new List<IObjectValidationRule>();
            m_ValidationResults = new List<ValidationResult>();
        }

        IEnumerator<IObjectValidationRule> IEnumerable<IObjectValidationRule>.GetEnumerator()
        {
            return m_Rules.GetEnumerator();
        }

        IEnumerator IEnumerable.GetEnumerator()
        {
            return m_Rules.GetEnumerator();
        }

        /// <summary>
        /// Adds new rule.
        /// </summary>
        /// <param name="rule">Rule to be added.</param>
        public void Add(IObjectValidationRule rule)
        {
            if (rule == null)
                throw new ArgumentNullException("rule");

            m_Rules.Add(rule);
        }

        /// <summary>
        /// Adds new validation callback.
        /// </summary>
        /// <param name="callback">Callback to be added.</param>
        public void Add(ValidateObjectCallback callback)
        {
            if (callback == null)
                throw new ArgumentNullException("callback");

            Add(new DelegateObjectValidationRule(callback));
        }

        public void AddValidationResult(ValidationResult result)
        {
            m_ValidationResults.Add(result);
        }

        public void ClearValidation()
        {
            m_ValidationResults.Clear();
        }
    }
}