﻿//==============================================================================
// File: ValidatableBase.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.ComponentModel;
using WpfRcp.PropertyModel.Internal.Common;
using System.Linq.Expressions;

namespace WpfRcp.PropertyModel.Validation
{
    /// <summary>
    /// Base class for object which can be validated.
    /// </summary>
    public abstract class ValidatableBase : IValidatable, INotifyPropertyChanged
    {
        #region IValidatable Implementation

        /// <summary>
        /// Gets a value indicating whether object is in valid state.
        /// </summary>
        public abstract bool IsValid { get; }

        [field: NonSerialized]
        public event EventHandler<EventArgs> ObjectStateChanged;

        protected virtual void OnObjectStateChanged()
        {
            if (ObjectStateChanged != null)
                ObjectStateChanged(this, EventArgs.Empty);
        }

        #endregion

        #region INotifyPropertyChanged Implementation

        [field: NonSerialized]
        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string property)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new System.ComponentModel.PropertyChangedEventArgs(property));

            OnObjectStateChanged();
        }

        protected void OnPropertyChanged<T>(Expression<Func<T, object>> property)
        {
            OnPropertyChanged(typeof(T).GetPropertyName(property));
        }

        #endregion
    }
}