﻿//==============================================================================
// File: ValidationArgs.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with WpfRcp. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;

namespace WpfRcp.PropertyModel.Validation
{
    /// <summary>
    /// Defines property validation arguments.
    /// </summary>
    [Serializable]
    public class ValidationArgs
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ValidationArgs"/> class.
        /// </summary>
        /// <param name="source">Source <see cref="IPropertyContainer"/>
        /// instance for which the property is being validated.</param>
        /// <param name="property">The property being validated.</param>
        public ValidationArgs(IPropertyContainer source, MetaProperty property)
        {
            Source = source;
            Property = property;
        }

        /// <summary>
        /// Gets the source <see cref="IPropertyContainer"/> instance for which the
        /// property is being validated.
        /// </summary>
        public IPropertyContainer Source { get; private set; }

        /// <summary>
        /// Gets the property being validated.
        /// </summary>
        public MetaProperty Property { get; private set; }
    }
}