﻿//==============================================================================
// File: LogWindowListener.cs
// Created: 2010-05-28
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================
using System;
using System.Diagnostics;
using WpfRcp.Services;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging.TraceListeners;
using Microsoft.Practices.ServiceLocation;

namespace WpfRcp.Logging.EnterpriseLibrary
{
    /// <summary>
    /// Trace listener that writes formatted messages to the Log Window.
    /// </summary>
    [ConfigurationElementType(typeof(CustomTraceListenerData))]
    public class LogWindowListener : CustomTraceListener
    {
        private readonly LogManager m_LogManager;

        public LogWindowListener()
        {
            if (ServiceLocator.Current != null)
            {
                m_LogManager = ServiceLocator.Current.GetInstance<LogManager>();
            }
        }

        public override void TraceData(TraceEventCache eventCache, string source, TraceEventType eventType, int id, object data)
        {
            if (data is LogEntry && Formatter != null)
            {
                WriteLine(data);
            }
            else
            {
                WriteLine(data.ToString());
            }
        }

        /// <summary>
        /// Writes a message to the debug window.
        /// </summary>
        /// <param name="message">The string to write to the log window.</param>
        public override void Write(string message)
        {
            Debug.Write(message);
        }

        /// <summary>
        /// Writes a message to the debug window.
        /// </summary>
        /// <param name="message">The string to write to the log window.</param>
        public override void WriteLine(string message)
        {
            Debug.WriteLine(message);
        }

        /// <summary>
        /// Writes a message to the log window.
        /// </summary>
        /// <param name="o">The object to write to the log window.</param>
        public override void WriteLine(object o)
        {
            if (m_LogManager != null)
            {
                var logEntry = o as LogEntry;
                m_LogManager.AddEntry(new EntLibLogEntry(logEntry));
            }
        }
    }
}