﻿//==============================================================================
// File: PresentationModelBehavior.cs
// Created: 2010-05-28
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Globalization;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using Caliburn.PresentationFramework.ApplicationModel;
using Microsoft.Practices.ServiceLocation;

namespace WpfRcp.Controls.Behaviors
{
    public class PresentationModelBehavior
    {
        public static Type GetPresenterType(DependencyObject obj)
        {
            return (Type)obj.GetValue(PresenterTypeProperty);
        }

        public static void SetPresenterType(DependencyObject obj, Type value)
        {
            obj.SetValue(PresenterTypeProperty, value);
        }

        public static readonly DependencyProperty PresenterTypeProperty =
            DependencyProperty.RegisterAttached("PresenterType", typeof(Type), typeof(PresentationModelBehavior),
                new UIPropertyMetadata(null, OnPresenterTypeChanged));

        private static void OnPresenterTypeChanged(DependencyObject d, DependencyPropertyChangedEventArgs args)
        {
            var control = (Control) d;
            var type = (Type) args.NewValue;
            if (type != null)
            {
                var model = ServiceLocator.Current.GetInstance(type);
                var binder = ServiceLocator.Current.GetInstance<IBinder>();
                binder.Bind(model, control, null);
            }
        }
    }

    public class PresentationModelConverter : IValueConverter
    {
        #region Implementation of IValueConverter

        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            return Binding.DoNothing;
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var control = value as Control;
            if (control == null) return Binding.DoNothing;
            
            return control.DataContext;
        }

        #endregion
    }
}