﻿//==============================================================================
// File: ContainerCommand.cs
// Created: 2010-11-25
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System.Windows;
using System.Windows.Controls.Primitives;
using System.Windows.Input;
using Microsoft.Practices.ServiceLocation;

namespace WpfRcp.Core.Commands
{
    public static class ContainerCommand
    {
        public static string GetAttach(DependencyObject obj)
        {
            return (string)obj.GetValue(AttachProperty);
        }

        public static void SetAttach(DependencyObject obj, string value)
        {
            obj.SetValue(AttachProperty, value);
        }

        public static readonly DependencyProperty AttachProperty =
            DependencyProperty.RegisterAttached("Attach", typeof(string), typeof(ContainerCommand), new UIPropertyMetadata(OnAttachChanged));

        private static void OnAttachChanged(DependencyObject obj, DependencyPropertyChangedEventArgs args)
        {
            if (args.NewValue != null)
            {
                var commandName = (string) args.NewValue;
                var command = ServiceLocator.Current.GetInstance<ICommand>(commandName);

                if (command != null)
                {
                    obj.SetValue(ButtonBase.CommandProperty, command);
                }
            }
        }
    }
}