﻿//==============================================================================
// File: DependencyPropertyHelper.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Linq.Expressions;
using System.Windows;

namespace WpfRcp.Core.Common
{
    public static class DependencyPropertyHelper
    {
        public static DependencyProperty Register<TOwner>(
            Expression<Func<TOwner, object>> property)
        {
            return DependencyProperty.Register(typeof (TOwner).GetPropertyName(property),
                                               typeof (TOwner).GetPropertyType(property),
                                               typeof (TOwner));
        }

        public static DependencyProperty Register<TOwner>(
            Expression<Func<TOwner, object>> property, PropertyMetadata metadata)
        {
            return DependencyProperty.Register(typeof(TOwner).GetPropertyName(property),
                                               typeof(TOwner).GetPropertyType(property),
                                               typeof(TOwner),
                                               metadata);
        }

        public static DependencyProperty Register<TOwner>(
            Expression<Func<TOwner, object>> property,
            PropertyMetadata metadata,
            ValidateValueCallback validateValueCallback)
        {
            return DependencyProperty.Register(typeof(TOwner).GetPropertyName(property),
                                               typeof(TOwner).GetPropertyType(property),
                                               typeof(TOwner),
                                               metadata,
                                               validateValueCallback);
        }

        public static DependencyPropertyKey RegisterReadOnly<TOwner>(
            Expression<Func<TOwner, object>> property, PropertyMetadata metadata)
        {
            return DependencyProperty.RegisterReadOnly(typeof(TOwner).GetPropertyName(property),
                                                       typeof(TOwner).GetPropertyType(property),
                                                       typeof(TOwner),
                                                       metadata);
        }

        public static DependencyPropertyKey RegisterReadOnly<TOwner>(
            Expression<Func<TOwner, object>> property,
            PropertyMetadata metadata,
            ValidateValueCallback validateValueCallback)
        {
            return DependencyProperty.RegisterReadOnly(typeof(TOwner).GetPropertyName(property),
                                                       typeof(TOwner).GetPropertyType(property),
                                                       typeof(TOwner),
                                                       metadata,
                                                       validateValueCallback);
        }
    }
}