﻿//==============================================================================
// File: EventsHelper.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.ComponentModel;

namespace WpfRcp.Core.Common
{
    public static class EventsHelper
    {
        // For asynchronous event invocation
        private delegate void AsyncFireDelegate(Delegate del, params object[] args);

        private static void UnsafeFire(Delegate del, params object[] args)
        {
            if (del != null)
            {
                Delegate[] delegates = del.GetInvocationList();
                foreach (Delegate sink in delegates)
                {
                    try
                    {
                        sink.DynamicInvoke(args);
                    }
                    catch (Exception)
                    {
                    }
                }
            }
        }

        private static void AsyncUnsafeFire(Delegate del, params object[] args)
        {
            if (del != null)
            {
                Delegate[] delegates = del.GetInvocationList();
                foreach (Delegate sink in delegates)
                {
                    AsyncFireDelegate asyncFire = AsyncUnsafeFireHelper;

                    // No exception will be thrown since invoking in a separate thread
                    // using BeginInvoke
                    asyncFire.BeginInvoke(sink, args, null, null);
                }
            }
        }

        private static void AsyncUnsafeFireHelper(Delegate del, params object[] args)
        {
            del.DynamicInvoke(args);
        }

        public static void AsyncFire<T>(EventHandler<T> handler, object sender, T e) where T : EventArgs
        {
            AsyncUnsafeFire(handler, sender, e);
        }

        public static void Fire<T>(EventHandler<T> handler, object sender, T e) where T : EventArgs
        {
            UnsafeFire(handler, sender, e);
        }

        public static void Fire(PropertyChangedEventHandler handler, object sender, PropertyChangedEventArgs e)
        {
            UnsafeFire(handler, sender, e);
        }
    }
}