﻿//==============================================================================
// File: Theme.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;

namespace WpfRcp.Core.Common
{
    /// <summary>
    /// Represents Mammoth theme.
    /// </summary>
    public class Theme
    {
        private readonly string m_Name;

        /// <summary>
        /// Initializes a new instance of the <see cref="Theme"/> class.
        /// </summary>
        /// <param name="name">Name of a theme.</param>
        public Theme(string name)
        {
            if (string.IsNullOrEmpty(name))
                throw new ArgumentNullException("name");

            m_Name = name;
        }
        
        /// <summary>
        /// Gets the name of this theme.
        /// </summary>
        public string Name
        {
            get { return m_Name; }
        }

        public static explicit operator Theme(string input)
        {
            return new Theme(input);
        }

        public static explicit operator string(Theme input)
        {
            return input.Name;
        }

        public bool Equals(Theme other)
        {
            if (ReferenceEquals(null, other)) return false;
            if (ReferenceEquals(this, other)) return true;
            return Equals(other.m_Name, m_Name);
        }

        public override bool Equals(object obj)
        {
            if (ReferenceEquals(null, obj)) return false;
            if (ReferenceEquals(this, obj)) return true;
            if (obj.GetType() != typeof (Theme)) return false;
            return Equals((Theme) obj);
        }

        public override int GetHashCode()
        {
            return m_Name.GetHashCode();
        }
    }
}