﻿//==============================================================================
// File: TypeHelper.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Diagnostics.CodeAnalysis;
using System.Linq.Expressions;
using System.Reflection;

namespace WpfRcp.Core.Common
{
    public static class TypeHelper
    {
        private static PropertyInfo GetPropertyInternal(LambdaExpression propertyAccessor)
        {
            MemberExpression memberExpression;

            if (propertyAccessor.Body is UnaryExpression)
            {
                var ue = (UnaryExpression)propertyAccessor.Body;
                memberExpression = (MemberExpression)ue.Operand;
            }
            else
            {
                memberExpression = (MemberExpression)propertyAccessor.Body;
            }

            return (PropertyInfo)(memberExpression).Member;
        }

        [SuppressMessage("Microsoft.Design", "CA1006:DoNotNestGenericTypesInMemberSignatures")]
        [SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters",
            Justification = "Adds static compile-time checking to expression")]
        public static Type GetPropertyType<TObject>(Expression<Func<TObject, object>> propertyAccessor)
        {
            return GetPropertyInternal(propertyAccessor).PropertyType;
        }

        [SuppressMessage("Microsoft.Design", "CA1006:DoNotNestGenericTypesInMemberSignatures")]
        [SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters",
            Justification = "Adds static compile-time checking to expression")]
        public static string GetPropertyName<TObject>(Expression<Func<TObject, object>> propertyAccessor)
        {
            return GetPropertyInternal(propertyAccessor).Name;
        }

        [SuppressMessage("Microsoft.Design", "CA1006:DoNotNestGenericTypesInMemberSignatures")]
        [SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters",
            Justification = "Adds static compile-time checking to expression")]
        public static string GetPropertyName<TObject, T>(Expression<Func<TObject, T>> propertyAccessor)
        {
            return GetPropertyInternal(propertyAccessor).Name;
        }

        [SuppressMessage("Microsoft.Design", "CA1006:DoNotNestGenericTypesInMemberSignatures")]
        [SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters",
            Justification = "Adds static compile-time checking to expression")]
        public static string GetPropertyName<T>(Expression<Func<T>> propertyAccessor)
        {
            return GetPropertyInternal(propertyAccessor).Name;
        }

        [SuppressMessage("Microsoft.Design", "CA1006:DoNotNestGenericTypesInMemberSignatures")]
        [SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters",
            Justification = "Adds static compile-time checking to expression")]
        public static PropertyInfo GetProperty<TObject>(Expression<Func<TObject, object>> propertyAccessor)
        {
            return GetPropertyInternal(propertyAccessor);
        }

        [SuppressMessage("Microsoft.Design", "CA1006:DoNotNestGenericTypesInMemberSignatures")]
        [SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters",
            Justification = "Adds static compile-time checking to expression")]
        public static PropertyInfo GetProperty<TObject, T>(Expression<Func<TObject, T>> propertyAccessor)
        {
            return GetPropertyInternal(propertyAccessor);
        }

        [SuppressMessage("Microsoft.Design", "CA1006:DoNotNestGenericTypesInMemberSignatures")]
        [SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters",
            Justification = "Adds static compile-time checking to expression")]
        public static PropertyInfo GetProperty<T>(Expression<Func<T>> propertyAccessor)
        {
            return GetPropertyInternal(propertyAccessor);
        }
    }
}