﻿//==============================================================================
// File: IOperation.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;

namespace WpfRcp.Core.Operations
{
    /// <summary>
    /// Represents an operation.
    /// </summary>
    public interface IOperation
    {
        /// <summary>
        /// Returns display text.
        /// </summary>
        string Text { get; }

        /// <summary>
        /// Returns display description.
        /// </summary>
        string Description { get; }

        /// <summary>
        /// Gets or sets command's result. Keep in mind that not all commands return a result.
        /// </summary>
        object Result { get; }

        /// <summary>
        /// Gets the command associated with this operation.
        /// </summary>
        string Command { get; }

        /// <summary>
        /// Returns true if operation can be cancelled. False otherwise.
        /// </summary>
        bool IsCancelable { get; }

        /// <summary>
        /// Returns true if operation can be fired and leaved in foreground. False otherwise.
        /// </summary>
        bool IsBackgroundable { get; }

        /// <summary>
        /// Method that encapsulates operation logic.
        /// </summary>
        void Execute();
    }
}