﻿//==============================================================================
// File: IStatusManager.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using WpfRcp.Core.Services.Status;
using WpfRcp.Core.Threading;
using WpfRcp.Core.Views;

namespace WpfRcp.Core.Services
{
    /// <summary>
    /// Manages status notification in application.
    /// </summary>
    public interface IStatusManager
    {
        /// <summary>
        /// Creates wait cursor (usable for operations which utilizes UI thread).
        /// </summary>
        /// <returns></returns>
        IDisposable CreateWaitCursor();

        /// <summary>
        /// Creates simple non-deterministic status monitor.
        /// </summary>
        /// <param name="taskName">Name of the task.</param>
        /// <param name="job">Job which will be executed.</param>
        /// <param name="progressView">Progress view to display.</param>
        /// <returns>Simple status monitor.</returns>
        ISimpleRcpStatusMonitor CreateSimpleStatusMonitor(string taskName, Job job, IProgressView progressView);

        /// <summary>
        /// Creates simple non-deterministic status monitor.
        /// </summary>
        /// <param name="taskName">Name of the task.</param>
        /// <param name="isBackgroundable">Determines if task is backgroundable.</param>
        /// <param name="isCancelable">Determines if task is cancelable.</param>
        /// <param name="cancelAction">Action to execute when cancel is invoked.</param>
        /// <param name="progressView">Progress view to display.</param>
        /// <returns></returns>
        ISimpleRcpStatusMonitor CreateSimpleStatusMonitor(string taskName, bool isBackgroundable, bool isCancelable, Action cancelAction, IProgressView progressView);

        /// <summary>
        /// Creates simple deterministic status monitor.
        /// </summary>
        /// <param name="taskName">Name of the task.</param>
        /// <param name="job">Job which will be executed.</param>
        /// <param name="progressView">Progress view to display.</param>
        /// <returns>Status monitor.</returns>
        IRcpStatusMonitor CreateStatusMonitor(string taskName, Job job, IProgressView progressView);

        /// <summary>
        /// Creates simple deterministic status monitor.
        /// </summary>
        /// <param name="taskName">Name of the task.</param>
        /// /// <param name="isBackgroundable">Determines if task is backgroundable.</param>
        /// <param name="isCancelable">Determines if task is cancelable.</param>
        /// <param name="cancelAction">Action to execute when cancel is invoked.</param>
        /// <param name="progressView">Progress view to display.</param>
        /// <returns>Status monitor.</returns>
        IRcpStatusMonitor CreateStatusMonitor(string taskName, bool isBackgroundable, bool isCancelable, Action cancelAction, IProgressView progressView);
    }
}