﻿//==============================================================================
// File: WpfJobEventDispatcher.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Windows.Threading;

namespace WpfRcp.Core.Threading.Internal
{
    internal class WpfJobEventDispatcher : IJobEventDispatcher
    {
        public static readonly IJobEventDispatcher Default = new WpfJobEventDispatcher();

        public void Perform(Delegate del, object[] args)
        {
            if (System.Windows.Application.Current.Dispatcher.CheckAccess() == false)
            {
                if (args != null && args.Length > 0)
                {
                    if (args.Length > 1)
                    {
                        var args2 = new object[args.Length - 1];
                        for (int i = 1; i < args.Length; i++)
                        {
                            args2[i - 1] = args[i];
                        }

                        System.Windows.Application.Current.Dispatcher.Invoke(DispatcherPriority.Normal, del, args[0], args2);
                    }
                    else
                    {
                        System.Windows.Application.Current.Dispatcher.Invoke(DispatcherPriority.Normal, del, args[0]);
                    }
                }
                else
                {
                    System.Windows.Application.Current.Dispatcher.Invoke(DispatcherPriority.Normal, del);
                }
            }
            else
            {
                del.DynamicInvoke(args);
            }
        }
    }
}