﻿//==============================================================================
// File: JobOptions.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

namespace WpfRcp.Core.Threading
{
    /// <summary>
    /// Represents job options.
    /// </summary>
    public class JobOptions
    {
        /// <summary>
        /// Represents default job options.
        /// </summary>
        public static readonly JobOptions Default = new JobOptions(false, false, JobThreadOptions.UIThread);

        /// <summary>
        /// Constructs a new instance of <see cref="JobOptions"/> class.
        /// </summary>
        /// <param name="isCancelable">Indicates if the job can be cancelled.</param>
        /// <param name="isBackgroundable">Indicates if the job can be run in background.</param>
        public JobOptions(bool isCancelable, bool isBackgroundable)
            : this(isCancelable, isBackgroundable, JobThreadOptions.UIThread)
        {
        }

        /// <summary>
        /// Constructs a new instance of <see cref="JobOptions"/> class.
        /// </summary>
        /// <param name="isCancelable">Indicates if the job can be cancelled.</param>
        /// <param name="isBackgroundable">Indicates if the job can be run in background.</param>
        /// <param name="threadOption">Indicates in which thread job events will be executed.</param>
        public JobOptions(bool isCancelable, bool isBackgroundable, JobThreadOptions threadOption)
        {
            IsCancelable = isCancelable;
            IsBackgroundable = isBackgroundable;
            ThreadOption = threadOption;
        }

        /// <summary>
        /// Gets if the job can be cancelled.
        /// </summary>
        public bool IsCancelable { get; private set; }

        /// <summary>
        /// Gets if the job can be fired and left in foreground.
        /// </summary>
        public bool IsBackgroundable { get; private set; }

        /// <summary>
        /// Gets a thread option.
        /// </summary>
        public JobThreadOptions ThreadOption { get; private set; }
    }
}