﻿//==============================================================================
// File: IView.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.ComponentModel;

namespace WpfRcp.Core.Views
{
    /// <summary>
    /// Base interfaces for all views of type window.
    /// </summary>
    public interface IView
    {
        /// <summary>
        /// Occurs when the window is about to close.
        /// </summary>
        event EventHandler Closed;

        /// <summary>
        /// Occurs directly after <see cref="Close"/>
        /// is called, and can be handled to cancel window closure.
        /// </summary>
        event CancelEventHandler Closing;

        /// <summary>
        /// Shows the view.
        /// </summary>
        void Show();

        /// <summary>
        /// Shows view in modal manner.
        /// </summary>
        /// <returns></returns>
        bool? ShowDialog();

        /// <summary>
        /// Closes the view.
        /// </summary>
        void Close();

        /// <summary>
        /// Sets the view owner.
        /// </summary>
        object ViewOwner { set; }

        /// <summary>
        /// Gets or sets the value indicating whether the view is maximized or not.
        /// </summary>
        bool IsMaximized { get; set; }

        /// <summary>
        /// Gets or sets width of the view.
        /// </summary>
        double Width { get; set; }

        /// <summary>
        /// Gets or sets height of the view.
        /// </summary>
        double Height { get; set; }

        /// <summary>
        /// Gets or sets top position  of the view.
        /// </summary>
        double Top { get; set; }

        /// <summary>
        /// Gets or sets left position of the view.
        /// </summary>
        double Left { get; set; }

        /// <summary>
        /// Attempts to set focus to the view.
        /// </summary>
        /// <returns></returns>
        bool Focus();
    }
}