﻿//==============================================================================
// File: WindowPresentationModelBase.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Windows;

namespace WpfRcp.Core.Views.Presenters
{
    public class WindowPresentationModelBase<TView> : PresenterBase<TView>
        where TView : class, IView
    {
        protected override void Initialize()
        {
            View.Closed += ((sender, args) => OnClosed());
            View.Closing += ((sender, args) => { args.Cancel = OnClosing(); });

            var window = View as Window;
            if (window != null)
            {
                window.Loaded += (sender, args) => Loaded();
            }
        }

        /// <summary>
        /// Method called whenever view is closed.
        /// </summary>
        protected virtual void OnClosed()
        {
        }

        /// <summary>
        /// Method called when a view is about to close.
        /// </summary>
        /// <returns>Return true if view shouldn't be closed. False otherwise.</returns>
        protected virtual bool OnClosing()
        {
            return false;
        }

        protected virtual void Loaded()
        {
            
        }
    }
}