﻿//==============================================================================
// File: ShellAnimationController.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System.Windows;
using System.Windows.Media.Animation;
using WpfRcp.Core.Services;
using WpfRcp.Core.Views;

namespace WpfRcp.Controllers
{
    public class ShellAnimationController
    {
        private readonly IApplicationSettings m_Settings;
        private bool m_FirstAnimation;

        public ShellAnimationController(IApplicationSettings settings)
        {
            m_Settings = settings;
            m_FirstAnimation = true;
        }

        public bool VerifyStoryboards(IShell shell)
        {
            var window = (Window) shell;
            var s1 = (Storyboard)window.Resources["Intro"];
            var s2 = (Storyboard)window.Resources["HeaderAppeared"];
            var s3 = (Storyboard)window.Resources["HeaderGone"];

            return s1 != null && s2 != null && s3 != null;
        }

        public void Animate(IShell shell)
        {
            var window = (Window)shell;
            if (m_FirstAnimation)
            {
                m_FirstAnimation = false;

                var intro = (Storyboard)window.Resources["Intro"];
                if (m_Settings.IsHeaderVisible == false)
                {
                    intro.Completed += ((sender, args) =>
                                        window.BeginStoryboard((Storyboard)window.Resources["HeaderGone"]));
                }

                window.BeginStoryboard(intro);
                return;
            }

            if (m_Settings.IsHeaderVisible)
            {
                window.BeginStoryboard((Storyboard) window.Resources["HeaderAppeared"]);
            }
            else
            {
                window.BeginStoryboard((Storyboard) window.Resources["HeaderGone"]);
            }
        }
    }
}