﻿//==============================================================================
// File: AppMessageBoxExceptionHandler.cs
// Created: 2010-05-10
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Collections.Specialized;
using WpfRcp.Core.Views;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling.Configuration;
using Microsoft.Practices.ServiceLocation;

namespace WpfRcp.Helpers.Logging
{
    /// <summary>
    /// Summary description for AppMessageBoxExceptionHandler.
    /// </summary>
    [ConfigurationElementType(typeof(CustomHandlerData))]
    public class AppMessageBoxExceptionHandler : IExceptionHandler
    {
        private readonly string m_Caption;
        private readonly string m_Message;

        public AppMessageBoxExceptionHandler(NameValueCollection collection)
        {
            m_Caption = collection["caption"];
            m_Message = collection["message"];
        }

        public Exception HandleException(Exception exception, Guid handlingInstanceId)
        {
            var messageBox = ServiceLocator.Current.GetInstance<IMessageBox>();
            messageBox.Show(m_Caption, m_Message, MessageBoxViewButtons.OK, MessageBoxViewIcons.Error);

            return exception;
        }
    }
}