﻿//==============================================================================
// File: MenuItem.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Windows;
using WpfRcp.Core.Common;
using WpfRcp.Core.Services.Commands;

namespace WpfRcp.Services.Commands
{
    public class MenuItem : IMenuItem
    {
        public MenuItem(string name)
        {
            Name = name;
            RegisterExtension = true;
        }

        public string Name { get; private set; }

        public string Text { get; set; }

        public string Description { get; set; }

        public object Icon { get; set; }

        public bool RegisterExtension { get; set; }

        public int Position { get; set; }

        public ICommandDescriptor Command { get; set; }

        public IMenuItemGroup Group { get; set; }

        private DependencyObject m_Visual;
        public DependencyObject Visual
        {
            get { return m_Visual; }
            set
            {
                m_Visual = value;
                OnVisualCreated();
            }
        }

        public event EventHandler VisualCreated;

        public IMenuItem SetText(string text)
        {
            Text = text;
            return this;
        }

        public IMenuItem SetDescription(string description)
        {
            Description = description;
            return this;
        }

        public IMenuItem SetIcon(object icon)
        {
            Icon = icon;
            return this;
        }

        public IMenuItem SetPosition(int position)
        {
            Position = position;
            return this;
        }

        private void OnVisualCreated()
        {
            if (VisualCreated != null)
                VisualCreated(this, EventArgs.Empty);
        }
    }    
}