﻿//==============================================================================
// File: MenuItemGroup.cs
// Created: 2010-06-07
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using WpfRcp.Core.Common;
using WpfRcp.Core.Services.Commands;

namespace WpfRcp.Services.Commands
{
    public class MenuItemGroup : IMenuItemGroup, IEquatable<MenuItemGroup>
    {
        public MenuItemGroup(string name, IMenuTab tab)
        {
            Name = name;
            MenuTab = tab;
        }

        public string Name { get; private set; }

        public string Text { get; set; }

        public int Position { get; set; }

        public IMenuTab MenuTab { get; private set; }

        public bool Equals(MenuItemGroup other)
        {
            if (ReferenceEquals(null, other)) return false;
            if (ReferenceEquals(this, other)) return true;

            return Equals(other.Name, Name);
        }

        public override bool Equals(object obj)
        {
            if (ReferenceEquals(null, obj)) return false;
            if (ReferenceEquals(this, obj)) return true;
            if (obj.GetType() != typeof(MenuItemGroup)) return false;

            return Equals((MenuItemGroup)obj);
        }

        public override int GetHashCode()
        {
            return Name.GetHashCode();
        }

        public static bool operator ==(MenuItemGroup left, MenuItemGroup right)
        {
            return Equals(left, right);
        }

        public static bool operator !=(MenuItemGroup left, MenuItemGroup right)
        {
            return !Equals(left, right);
        }
    }

}