﻿//==============================================================================
// File: RcpSettings.cs
// Created: 2010-05-28
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Windows.Media;
using WpfRcp.Core.Common;
using WpfRcp.Core.Services;

namespace WpfRcp.Services
{
    public class RcpSettings : BindableBase, IRcpSettings
    {
        private ImageSource m_WindowIcon;
        private ImageSource m_AboutBoxImage;
        private ImageSource m_SplashScreenImage;
        private string m_Authors;
        private string m_AnsiCopyright;
        private string m_Copyright;
        private string m_AppName;
        private string m_AppNameExtended;
        private string m_StatusMessageLeft;
        private string m_StatusMessageRight;
        private string m_TaskBarAppName;
        private string m_VersionSuffix;

        public ImageSource WindowIcon
        {
            get { return m_WindowIcon; }
            set
            {
                m_WindowIcon = value;
                OnPropertyChanged("WindowIcon");
            }
        }

        public ImageSource AboutBoxImage
        {
            get { return m_AboutBoxImage; }
            set
            {
                m_AboutBoxImage = value;
                OnPropertyChanged("AboutBoxImage");
            }
        }

        public ImageSource SplashScreenImage
        {
            get { return m_SplashScreenImage; }
            set
            {
                m_SplashScreenImage = value;
                OnPropertyChanged("SplashScreenImage");
            }
        }

        public string Authors
        {
            get { return m_Authors; }
            set
            {
                m_Authors = value;
                OnPropertyChanged<RcpSettings>(t => t.Authors);
            }
        }

        public string AppName
        {
            get { return m_AppName; }
            set
            {
                m_AppName = value;
                OnPropertyChanged("AppName");
            }
        }

        public string AppNameExtended
        {
            get { return m_AppNameExtended; }
            set
            {
                m_AppNameExtended = value;
                OnPropertyChanged("AppNameExtended");
            }
        }

        public string TaskBarAppName
        {
            get { return m_TaskBarAppName; }
            set
            {
                m_TaskBarAppName = value;
                OnPropertyChanged("TaskBarAppName");
            }
        }

        public string Copyright
        {
            get { return m_Copyright; }
            set
            {
                m_Copyright = value;
                OnPropertyChanged("Copyright");
            }
        }

        public string AnsiCopyright
        {
            get { return m_AnsiCopyright; }
            set
            {
                m_AnsiCopyright = value;
                OnPropertyChanged<RcpSettings>(t => t.AnsiCopyright);
            }
        }

        public string StatusMessageLeft
        {
            get { return m_StatusMessageLeft; }
            set
            {
                m_StatusMessageLeft = value;
                OnPropertyChanged("StatusMessageLeft");
            }
        }

        public string StatusMessageRight
        {
            get { return m_StatusMessageRight; }
            set
            {
                m_StatusMessageRight = value;
                OnPropertyChanged("StatusMessageRight");
            }
        }

        public string VersionSuffix
        {
            get { return m_VersionSuffix; }
            set
            {
                m_VersionSuffix = value;
                OnPropertyChanged("VersionSuffix");
            }
        }
    }
}
