﻿//==============================================================================
// File: ResourceManagerImpl.cs
// Created: 2010-10-15
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.IO;
using System.Reflection;
using System.Windows;
using WpfRcp.Core.Services;

namespace WpfRcp.Services
{
    public class ResourceManagerImpl : IResourceManager
    {
        #region Implementation of IResourceManager

        public Stream GetResource(Assembly assembly, string resourcePath)
        {
            if (assembly == null) throw new ArgumentNullException("assembly");
            if (resourcePath == null) throw new ArgumentNullException("resourcePath");

            var uriString = string.Format("pack://application:,,,/{0};component/{1}", assembly.GetName().Name, resourcePath);
            var resourceInfo = Application.GetResourceStream(new Uri(uriString));

            return resourceInfo != null ? resourceInfo.Stream : null;
        }

        public string GetTextResource(Assembly assembly, string resourcePath)
        {
            if (assembly == null) throw new ArgumentNullException("assembly");
            if (resourcePath == null) throw new ArgumentNullException("resourcePath");

            var reader = new StreamReader(GetResource(assembly, resourcePath));
            return reader.ReadToEnd();
        }
        
        #endregion
    }
}