﻿//==============================================================================
// File: SimpleRcpStatusMonitor.cs
// Created: 2010-05-28
// Author: Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using WpfRcp.Core.Common;
using WpfRcp.Core.Services.Status;

namespace WpfRcp.Services.Status
{
    public class SimpleRcpStatusMonitor : BindableBase, ISimpleRcpStatusMonitor
    {
        private string m_TaskName;
        private string m_SubtaskName;
        private bool m_Backgroundable;
        private bool m_Cancelable;

        public event EventHandler Disposed;
        public event EventHandler Canceled;
        public event EventHandler SentToBackground;

        public string TaskName
        {
            get { return m_TaskName; }
            set
            {
                m_TaskName = value;
                OnPropertyChanged<SimpleRcpStatusMonitor>(t => t.TaskName);
            }
        }

        public string SubtaskName
        {
            get { return m_SubtaskName; }
            set
            {
                m_SubtaskName = value;
                OnPropertyChanged<SimpleRcpStatusMonitor>(t => t.SubtaskName);
            }
        }

        public bool Cancelable
        {
            get { return m_Cancelable; }
            internal set
            {
                m_Cancelable = value;
                OnPropertyChanged<SimpleRcpStatusMonitor>(t => t.Cancelable);
            }
        }

        public bool Backgroundable
        {
            get { return m_Backgroundable; }
            internal set
            {
                m_Backgroundable = value;
                OnPropertyChanged<SimpleRcpStatusMonitor>(t => t.Backgroundable);
            }
        }

        public void Cancel()
        {
            if(Canceled != null)
            {
                Canceled(this, EventArgs.Empty);
            }
        }

        public void SendToBackground()
        {
            if(SentToBackground != null)
            {
                SentToBackground(this, EventArgs.Empty);
            }
        }

        public virtual void Dispose()
        {
            if(Disposed != null)
            {
                Disposed(this, EventArgs.Empty);
            }
        }
    }
}