﻿//==============================================================================
// File: UnityContainerFacade.cs
// Created: 2010-05-28
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Collections.Generic;
using WpfRcp.Core.Services;
using Microsoft.Practices.Unity;

namespace WpfRcp.Services
{
    public class UnityContainerFacade : ContainerFacadeBase
    {
        private readonly IUnityContainer m_Container;

        public UnityContainerFacade(IUnityContainer container)
        {
            if (container == null)
                throw new ArgumentNullException("container");

            m_Container = container;
        }

        protected override bool DoIsTypeRegistered(Type type)
        {
            return m_Container.IsRegistered(type);
        }

        protected override IContainerFacade DoBuildUp(object instance)
        {
            m_Container.BuildUp(instance);
            return this;
        }

        protected override object DoResolve(Type type, string name)
        {
            return m_Container.Resolve(type, name);
        }

        protected override IEnumerable<object> DoResolveAll(Type type)
        {
            return m_Container.ResolveAll(type);
        }
        
        protected override IContainerFacade DoRegister(Type from, Type to, string name, LifetimePolicy policy)
        {
            m_Container.RegisterType(from, to, name, ParseLifetime(policy));
            return this;
        }

        protected override IContainerFacade DoRegisterInstance(Type type, string name, object instance)
        {
            m_Container.RegisterInstance(type, name, instance);
            return this;
        }

        protected override IContainerFacade DoCreateChildContainer()
        {
            var parent = m_Container.CreateChildContainer();
            return new UnityContainerFacade(parent);
        }

        private static LifetimeManager ParseLifetime(LifetimePolicy policy)
        {
            if (policy == LifetimePolicy.Singleton)
                return new ContainerControlledLifetimeManager();

            if (policy == LifetimePolicy.Transient)
                return new TransientLifetimeManager();

            if (policy == LifetimePolicy.PerThread)
                return new PerThreadLifetimeManager();

            throw new InvalidOperationException();
        }
    }
}