﻿//==============================================================================
// File: ApplicationBase.cs
// Created: 2010-05-28
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Windows;
using WpfRcp.Core.Startup;
using WpfRcp.Resources;

namespace WpfRcp.Startup
{
    public abstract class ApplicationBase : Application, IApplication
    {
        private readonly BootstrapperBase m_BootstrapperBase;

        protected ApplicationBase()
        {
            // ReSharper disable DoNotCallOverridableMethodsInConstructor
            m_BootstrapperBase = GetBootstrapper();
            // ReSharper restore DoNotCallOverridableMethodsInConstructor

            // Add commons to the merge dictionary
            Resources.MergedDictionaries.Add(new Common());
        }

        protected abstract BootstrapperBase GetBootstrapper();

        protected override void OnStartup(StartupEventArgs e)
        {
            base.OnStartup(e);

            #if (DEBUG)
            
            RunInDebugMode(e);
            
            #else
            
            RunInReleaseMode(e);
            
            #endif
        }

        private void RunInDebugMode(StartupEventArgs e)
        {
            DispatcherUnhandledException += OnDispatcherUnhandledException;
            try
            {
                m_BootstrapperBase.Start(e.Args);
            }
            catch (Exception ex)
            {
                m_BootstrapperBase.StartupUnhandledException(ex);
                throw;
            }
        }

        private void RunInReleaseMode(StartupEventArgs e)
        {
            DispatcherUnhandledException += OnDispatcherUnhandledException;
            try
            {
                m_BootstrapperBase.Start(e.Args);
            }
            catch (Exception ex)
            {
                m_BootstrapperBase.StartupUnhandledException(ex);
            }
        }

        protected override void OnExit(ExitEventArgs e)
        {
            m_BootstrapperBase.Exit();

            base.OnExit(e);
        }

        #if (DEBUG)

        private void OnDispatcherUnhandledException(object sender, System.Windows.Threading.DispatcherUnhandledExceptionEventArgs e)
        {
            m_BootstrapperBase.UnhandledException(e.Exception);

            // Set as not handled
            e.Handled = false;
        }

        #else

        private void OnDispatcherUnhandledException(object sender, System.Windows.Threading.DispatcherUnhandledExceptionEventArgs e)
        {
            m_BootstrapperBase.UnhandledException(e.Exception);

            // Set as handled
            e.Handled = true;
        }

        #endif

        #region Implementation of IApplication

        public DependencyObject RootVisual
        {
            get { return MainWindow; }
            set { MainWindow = value as Window; }
        }

        #endregion
    }
}