﻿//==============================================================================
// File: JobsViewPresentationModel.cs
// Created: 2010-09-17
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using WpfRcp.Core.Services;
using WpfRcp.Core.Threading;
using WpfRcp.Core.Views.Presenters;
using Microsoft.Practices.Composite.Presentation.Commands;

namespace WpfRcp.Views.Presenters
{
    public class JobsViewPresentationModel : PresenterBase<IJobsView>
    {
        private readonly IRcpSettings m_RcpSettings;

        public DelegateCommand<Job> CancelOperationCommand { get; private set; }

        public JobsViewPresentationModel(IJobsView view, IRcpSettings rcpSettings)
        {
            m_RcpSettings = rcpSettings;

            CancelOperationCommand = new DelegateCommand<Job>(ExecuteCancelOperationCommand);
            
            View = view;
            View.PresentationModel = this;
        }

        public IRcpSettings RcpSettings
        {
            get { return m_RcpSettings; }
        }

        private static void ExecuteCancelOperationCommand(Job operation)
        {
            if (operation != null)
            {
                operation.Cancel();
            }
        }

        public string DisplayName
        {
            get { return Properties.Resources.Jobs; }
        }
    }
}