﻿//==============================================================================
// File: LoggerViewPresentationModel.cs
// Created: 2010-09-17
// Author: Piotr Włodek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System.Collections.ObjectModel;
using WpfRcp.Core.Services;
using WpfRcp.Core.Views.Presenters;
using WpfRcp.Services;
using Microsoft.Practices.Composite.Presentation.Commands;

namespace WpfRcp.Views.Presenters
{
    public class LoggerViewPresentationModel : PresenterBase<ILoggerView>
    {
        private readonly IRcpSettings m_RcpSettings;
        private readonly LogManager m_LogManager;

        public DelegateCommand<object> ClearLogCommand { get; private set; }

        public LoggerViewPresentationModel(ILoggerView view, IRcpSettings rcpSettings, LogManager logManager)
        {
            m_RcpSettings = rcpSettings;
            m_LogManager = logManager;

            ClearLogCommand = new DelegateCommand<object>(ExecuteClearLogCommand);
            
            View = view;
            View.PresentationModel = this;
        }

        public IRcpSettings RcpSettings
        {
            get { return m_RcpSettings; }
        }

        public ReadOnlyObservableCollection<ILogEntry> ReadOnlyLogEntries
        {
            get { return m_LogManager.ReadOnlyLogEntries; }
        }

        private void ExecuteClearLogCommand(object args)
        {
            m_LogManager.Clear();
        }

        public string DisplayName
        {
            get { return Properties.Resources.Log; }
        }
    }
}