﻿//==============================================================================
// File: SplashViewPresentationModel.cs
// Created: 2010-05-28
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System;
using System.Reflection;
using WpfRcp.Core.Services;
using WpfRcp.Core.Views.Presenters;
using StringResources = WpfRcp.Properties.Resources;

namespace WpfRcp.Views.Presenters
{
    public class SplashViewPresentationModel : PresenterBase<ISplashView>
    {
        private readonly IRcpSettings m_RcpSettings;
        private string m_VersionString;
        private string m_RcpVersionString;
        private string m_StatusString;
        private bool m_StatusStringVisible;
        
        public SplashViewPresentationModel(ISplashView view, IRcpSettings rcpSettings)
        {
            m_RcpSettings = rcpSettings;
            View = view;
            View.PresentationModel = this;

            DataBind();
        }

        private void DataBind()
        {
            VersionString = string.Format(IntPtr.Size == 4 ?
                StringResources.VersionString32 : 
                StringResources.VersionString64, Assembly.GetEntryAssembly().GetName().Version);

            RcpVersionString = string.Format(IntPtr.Size == 4 ?
                StringResources.VersionString32 :
                StringResources.VersionString64, Assembly.GetExecutingAssembly().GetName().Version);
        }

        public string VersionString
        {
            get { return m_VersionString; }
            set
            {
                m_VersionString = value;
                OnPropertyChanged("VersionString");
            }
        }

        public string RcpVersionString
        {
            get { return m_RcpVersionString; }
            set
            {
                m_RcpVersionString = value;
                OnPropertyChanged("RcpVersionString");
            }
        }

        public string StatusString
        {
            get { return m_StatusString; }
            set
            {
                m_StatusString = value;
                OnPropertyChanged("StatusString");
            }
        }

        public bool StatusStringVisible
        {
            get { return m_StatusStringVisible; }
            set
            {
                m_StatusStringVisible = value;
                OnPropertyChanged("StatusStringVisible");
            }
        }

        public IRcpSettings RcpSettings
        {
            get { return m_RcpSettings; }
        }
    }
}