﻿//==============================================================================
// File: ThreadingOptionsViewPresentationModel.cs
// Created: 2010-05-28
// Author: Piotr Włodek, Arkadiusz Świerczek
//==============================================================================
// This file is a part of MAMMOTH project.
// Copyright (C) 2010 AGH University of Science and Technology, Krakow.
// https://caribou.iisg.agh.edu.pl/trac/mammoth
//
// Mammoth is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Mammoth is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with Mammoth. If not, see http://www.gnu.org/licenses/.
//==============================================================================

using System.Globalization;
using WpfRcp.Core.Globals;
using WpfRcp.Core.Services;
using WpfRcp.Core.Views.Presenters;
using Microsoft.Practices.Composite.Events;
using Microsoft.Practices.Composite.Presentation.Events;

namespace WpfRcp.Views.Presenters
{
    public class ThreadingOptionsViewPresentationModel : PresenterBase<IThreadingOptionsView>
    {
        private readonly IApplicationSettings m_Settings;
        private object m_Header;

        public ThreadingOptionsViewPresentationModel(IApplicationSettings settings,
            IEventAggregator eventAggregator)
        {
            eventAggregator.GetEvent<LanguageChangedEvent>().Subscribe(
                OnLanguageChangedHandler, ThreadOption.UIThread, true);

            m_Settings = settings;
            Header = Properties.Resources.Threading;
        }

        private void OnLanguageChangedHandler(CultureInfo cultureInfo)
        {
            Header = Properties.Resources.Threading;
        }

        public IApplicationSettings Settings
        {
            get { return m_Settings; }
        }

        public object Header
        {
            get { return m_Header; }
            set
            {
                m_Header = value;
                OnPropertyChanged("Header");
            }
        }
    }
}